@@ -100,7 +100,7 @@ error(const char *message, ...)
   putc('\n', stderr);
 }
 
-void
+static void
 short_usage(void)
 {
   fprintf(stderr, "Usage: %s [OPTION]... [INPUT [OUTPUT]]\n\
@@ -108,7 +108,7 @@ Try `%s --help' for more information.\n",
 	  program_name, program_name);
 }
 
-void
+static void
 usage(void)
 {
   printf("\
@@ -172,7 +172,7 @@ pfa_output_binary(unsigned char *data, int len)
 }
 
 static void
-pfa_output_end()
+pfa_output_end(void)
 {
 }
 
@@ -235,7 +235,7 @@ main(int argc, char *argv[])
 
      case VERSION_OPT:
       printf("t1ascii (LCDF t1utils) %s\n", VERSION);
-      printf("Copyright (C) 1992-2003 I. Lee Hetherington, Eddie Kohler et al.\n\
+      printf("Copyright (C) 1992-2010 I. Lee Hetherington, Eddie Kohler et al.\n\
 This is free software; see the source for copying conditions.\n\
 There is NO warranty, not even for merchantability or fitness for a\n\
 particular purpose.\n");
